==> xld-sql-migrations-10.2.0-628.1055-sources.jar: com/xebialabs/deployit/core/upgrade/service/SecurityUpgraderService.scala <==
package com.xebialabs.deployit.core.upgrade.service

import java.sql.ResultSet
import com.xebialabs.deployit.core.sql.{Queries, SchemaInfo}
import com.xebialabs.deployit.core.upgrade._
import com.xebialabs.deployit.plugin.api.reflect.Type
import com.xebialabs.deployit.repository.sql.base.pathToId
import org.springframework.beans.factory.annotation.{Autowired, Qualifier}
import org.springframework.jdbc.core.{JdbcTemplate, RowMapper}
import org.springframework.stereotype.Component
import org.springframework.transaction.PlatformTransactionManager
import org.springframework.transaction.annotation.Transactional

import scala.jdk.CollectionConverters._

trait SecurityUpgraderService extends Queries {
  def fetchCis(environmentType: String): List[ConfigurationItemData]

  def fetchOtherCis(): List[ConfigurationItemData]

  def fetchRoles(): List[RoleEntry]

  def fetchRoleRoles(): List[RoleRole]

  def fetchRolePrincipals(): List[RolePrincipal]

  def fetchRolePermissions(): List[PermissionEntry]
}

@Component
@Transactional("mainTransactionManager")
class DefaultSecurityUpgraderService(
                               @Autowired @Qualifier("mainSchema") val schemaInfo: SchemaInfo,
                               @Autowired @Qualifier("mainJdbcTemplate") val jdbcTemplate: JdbcTemplate,
                               @Autowired @Qualifier("mainTransactionManager") val transactionManager: PlatformTransactionManager
                             ) extends SecurityUpgraderService {


  def fetchCis(ciType: String): List[ConfigurationItemData] = {
    import CISSchema._
    jdbcTemplate.query(sqlb"SELECT $pathColumn, $nameColumn, $idColumn, $securedCiColumn, $ciTypeColumn from $tableName where $ciTypeColumn = ?",
      new RowMapper[ConfigurationItemData]() {
        override def mapRow(rs: ResultSet, rowNum: Int): ConfigurationItemData = {
          ConfigurationItemData(pathToId(rs.getString(1)), rs.getString(2), rs.getInt(3), rs.getInt(4), Type.valueOf(rs.getString(5)))
        }
      }, ciType).asScala.toList
  }

  def fetchOtherCis(): List[ConfigurationItemData] = {
    import CISSchema._
    jdbcTemplate.query(sqlb"SELECT $pathColumn, $nameColumn, $idColumn, $securedCiColumn, $ciTypeColumn from $tableName",
      new RowMapper[ConfigurationItemData]() {
        override def mapRow(rs: ResultSet, rowNum: Int): ConfigurationItemData = {
          ConfigurationItemData(pathToId(rs.getString(1)), rs.getString(2), rs.getInt(3), rs.getInt(4), Type.valueOf(rs.getString(5)))
        }
      }).asScala.toList
  }

  def fetchRoles(): List[RoleEntry] = {
    import RolesSchema.Roles._
    jdbcTemplate.query(sqlb"SELECT $ID, $NAME, $CI_ID from $tableName",
      new RowMapper[RoleEntry]() {
        override def mapRow(rs: ResultSet, rowNum: Int): RoleEntry = {
          RoleEntry(rs.getString(1), rs.getString(2), rs.getInt(3))
        }
      }).asScala.toList
  }

  def fetchRoleRoles(): List[RoleRole] = {
    import RolesSchema.RoleRoles._

    jdbcTemplate.query(sqlb"SELECT $ROLE_ID, $MEMBER_ROLE_ID from $tableName",
      new RowMapper[RoleRole]() {
        override def mapRow(rs: ResultSet, rowNum: Int): RoleRole = {
          RoleRole(rs.getString(1), rs.getString(2))
        }
      }).asScala.toList
  }

  def fetchRolePrincipals(): List[RolePrincipal] = {
    import RolesSchema.RolePrincipals._

    jdbcTemplate.query(sqlb"SELECT $ROLE_ID, $PRINCIPAL_NAME from $tableName",
      new RowMapper[RolePrincipal]() {
        override def mapRow(rs: ResultSet, rowNum: Int): RolePrincipal = {
          RolePrincipal(rs.getString(1), rs.getString(2))
        }
      }).asScala.toList
  }

  def fetchRolePermissions(): List[PermissionEntry] = {
    import PermissionsSchema._

    jdbcTemplate.query(sqlb"SELECT $ROLE_ID, $PERMISSION_NAME, $CI_ID from $tableName",
      new RowMapper[PermissionEntry]() {
        override def mapRow(rs: ResultSet, rowNum: Int): PermissionEntry = {
          PermissionEntry(rs.getString(1), rs.getString(2), rs.getInt(3))
        }
      }).asScala.toList
  }

}

==> xld-sql-migrations-10.4.0-1109.113-sources.jar: com/xebialabs/deployit/core/upgrade/service/SecurityUpgraderService.scala <==
package com.xebialabs.deployit.core.upgrade.service

import com.xebialabs.deployit.core.sql.spring.Setter

import java.sql.{PreparedStatement, ResultSet}
import com.xebialabs.deployit.core.sql.{Queries, SchemaInfo}
import com.xebialabs.deployit.core.upgrade._
import com.xebialabs.deployit.plugin.api.reflect.Type
import com.xebialabs.deployit.repository.sql.base.pathToId
import com.xebialabs.deployit.security.Role
import org.springframework.beans.factory.annotation.{Autowired, Qualifier}
import org.springframework.jdbc.core.{BatchPreparedStatementSetter, JdbcTemplate, RowMapper}
import org.springframework.stereotype.Component
import org.springframework.transaction.PlatformTransactionManager
import org.springframework.transaction.annotation.Transactional

import scala.jdk.CollectionConverters._

trait SecurityUpgraderService extends Queries {
  def fetchRoleByName(roleName: String): Option[RoleEntry]

  def fetchCis(environmentType: String): List[ConfigurationItemData]

  def fetchOtherCis(): List[ConfigurationItemData]

  def fetchRoles(): List[RoleEntry]

  def fetchRoleRoles(): List[RoleRole]

  def fetchRolePrincipals(): List[RolePrincipal]

  def fetchRolePermissions(): List[PermissionEntry]

  def insertRoles(roles: List[RoleEntry]): Unit

  def insertRolePermissions(rolePermissions: List[PermissionEntry]): Unit
}

@Component
@Transactional("mainTransactionManager")
class DefaultSecurityUpgraderService(
                               @Autowired @Qualifier("mainSchema") val schemaInfo: SchemaInfo,
                               @Autowired @Qualifier("mainJdbcTemplate") val jdbcTemplate: JdbcTemplate,
                               @Autowired @Qualifier("mainTransactionManager") val transactionManager: PlatformTransactionManager
                             ) extends SecurityUpgraderService {


  def fetchCis(ciType: String): List[ConfigurationItemData] = {
    import CISSchema._
    jdbcTemplate.query(sqlb"SELECT $pathColumn, $nameColumn, $idColumn, $securedCiColumn, $ciTypeColumn from $tableName where $ciTypeColumn = ?",
      new RowMapper[ConfigurationItemData]() {
        override def mapRow(rs: ResultSet, rowNum: Int): ConfigurationItemData = {
          ConfigurationItemData(pathToId(rs.getString(1)), rs.getString(2), rs.getInt(3), rs.getInt(4), Type.valueOf(rs.getString(5)))
        }
      }, ciType).asScala.toList
  }

  def fetchOtherCis(): List[ConfigurationItemData] = {
    import CISSchema._
    jdbcTemplate.query(sqlb"SELECT $pathColumn, $nameColumn, $idColumn, $securedCiColumn, $ciTypeColumn from $tableName",
      new RowMapper[ConfigurationItemData]() {
        override def mapRow(rs: ResultSet, rowNum: Int): ConfigurationItemData = {
          ConfigurationItemData(pathToId(rs.getString(1)), rs.getString(2), rs.getInt(3), rs.getInt(4), Type.valueOf(rs.getString(5)))
        }
      }).asScala.toList
  }

  def fetchRoles(): List[RoleEntry] = {
    import RolesSchema.Roles._
    jdbcTemplate.query(sqlb"SELECT $ID, $NAME, $CI_ID from $tableName",
      new RowMapper[RoleEntry]() {
        override def mapRow(rs: ResultSet, rowNum: Int): RoleEntry = {
          RoleEntry(rs.getString(1), rs.getString(2), rs.getInt(3))
        }
      }).asScala.toList
  }

  def fetchRoleRoles(): List[RoleRole] = {
    import RolesSchema.RoleRoles._

    jdbcTemplate.query(sqlb"SELECT $ROLE_ID, $MEMBER_ROLE_ID from $tableName",
      new RowMapper[RoleRole]() {
        override def mapRow(rs: ResultSet, rowNum: Int): RoleRole = {
          RoleRole(rs.getString(1), rs.getString(2))
        }
      }).asScala.toList
  }

  def fetchRolePrincipals(): List[RolePrincipal] = {
    import RolesSchema.RolePrincipals._

    jdbcTemplate.query(sqlb"SELECT $ROLE_ID, $PRINCIPAL_NAME from $tableName",
      new RowMapper[RolePrincipal]() {
        override def mapRow(rs: ResultSet, rowNum: Int): RolePrincipal = {
          RolePrincipal(rs.getString(1), rs.getString(2))
        }
      }).asScala.toList
  }

  def fetchRolePermissions(): List[PermissionEntry] = {
    import PermissionsSchema._

    jdbcTemplate.query(sqlb"SELECT $ROLE_ID, $PERMISSION_NAME, $CI_ID from $tableName",
      new RowMapper[PermissionEntry]() {
        override def mapRow(rs: ResultSet, rowNum: Int): PermissionEntry = {
          PermissionEntry(rs.getString(1), rs.getString(2), rs.getInt(3))
        }
      }).asScala.toList
  }

  override def insertRoles(roles: List[RoleEntry]): Unit = {
    import RolesSchema.Roles._

    jdbcTemplate.batchUpdate(sqlb"INSERT INTO $tableName  ($ID , $NAME, $CI_ID) VALUES (?,?,?)",
      new BatchPreparedStatementSetter {
        override def getBatchSize: Int = roles.size

        override def setValues(ps: PreparedStatement, i: Int): Unit = {
          ps.setString(1, roles(i).id)
          Setter.setStringForReporting(ps, 2, roles(i).name)
          ps.setInt(3, roles(i).ciId)
        }
      })
  }

  override def insertRolePermissions(rolePermissions: List[PermissionEntry]): Unit = {
    import PermissionsSchema._

    jdbcTemplate.batchUpdate(sqlb"INSERT INTO $tableName  ($ROLE_ID , $PERMISSION_NAME, $CI_ID) VALUES (?,?,?)",
      new BatchPreparedStatementSetter {
        override def getBatchSize: Int = rolePermissions.size

        override def setValues(ps: PreparedStatement, i: Int): Unit = {
          ps.setString(1, rolePermissions(i).roleId)
          Setter.setStringForReporting(ps,2, rolePermissions(i).permissionName)
          ps.setInt(3, rolePermissions(i).ciId)
        }
      })
  }

  override def fetchRoleByName(roleName: String): Option[RoleEntry] = {
    import RolesSchema.Roles._
    jdbcTemplate.query(sqlb"SELECT $ID, $NAME, $CI_ID from $tableName where $NAME = ?",
      new RowMapper[RoleEntry]() {
        override def mapRow(rs: ResultSet, rowNum: Int): RoleEntry = {
          RoleEntry(rs.getString(1), rs.getString(2), rs.getInt(3))
        }
      }, roleName).asScala.headOption
  }
}
